AgentChatView class
Embeddable conversation with no application shell or backend dependency.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AgentChatView
Constructors
- AgentChatView({Key? key, required ChatSession session, MarkdownTapLinkCallback? onTapLink, VoidCallback? onNewSession, PromptAttachmentController? attachmentController, PromptAttachmentPicker? pickAttachments, PromptAttachmentKindPicker? pickAttachmentsForKind, PromptImageClipboardReader? readClipboardImage, PromptDroppedImageReader? readDroppedImage, ChatImageDecodeBudgetLedger? imageDecodeLedger, BoundedImageDecoder boundedImageDecoder = const DartUiBoundedImageDecoder(), ToolPresentationRegistry? toolPresentationRegistry, ChatPartBuilder? timelineBuilder, ChatPartBuilder? composerBuilder, bool showError = true})
-
const
Properties
- attachmentController → PromptAttachmentController?
-
final
- boundedImageDecoder → BoundedImageDecoder
-
final
- composerBuilder → ChatPartBuilder?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageDecodeLedger → ChatImageDecodeBudgetLedger?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onNewSession → VoidCallback?
-
final
- onTapLink → MarkdownTapLinkCallback?
-
final
- pickAttachments → PromptAttachmentPicker?
-
final
- pickAttachmentsForKind → PromptAttachmentKindPicker?
-
final
- readClipboardImage → PromptImageClipboardReader?
-
final
- readDroppedImage → PromptDroppedImageReader?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → ChatSession
-
final
- showError → bool
-
final
- timelineBuilder → ChatPartBuilder?
-
final
- toolPresentationRegistry → ToolPresentationRegistry?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited