ChatSession class abstract
A session is owned by the host. Widgets only subscribe/unsubscribe; they never close agent connections, destroy history, or dispose this object.
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ChatSessionState
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
clearQueuedPrompts(
) → void -
guideQueuedPrompt(
int id) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeQueuedPrompt(
int id) → void -
reorderQueuedPrompt(
int oldIndex, int newIndex) → void -
resolvePermission(
ChatPermissionDecision decision) → Future< void> -
selectPermissionOption(
String optionId) → Future< void> -
send(
String text, {List< PromptAttachment> attachments = const []}) → Future<void> -
setConfigOption(
String id, Object value) → Future< void> -
setExecutionPolicy(
ChatToolCallExecutionPolicy policy) → void -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited