ChatThemeData class

Per-conversation appearance. Defaults preserve the desktop application's UI.

Constructors

ChatThemeData({Map<String, Color> colors = const {}, double contentMaxWidth = 800})
const

Properties

accent Color
no setter
accentBorder Color
no setter
accentDark Color
no setter
accentMist Color
no setter
accentSoft Color
no setter
bg Color
no setter
border Color
no setter
borderSoft Color
no setter
colors Map<String, Color>
final
contentMaxWidth double
final
danger Color
no setter
disabled Color
no setter
focusRing Color
no setter
hashCode int
The hash code for this object.
no setterinherited
primary Color
no setter
primaryDark Color
no setter
primaryMist Color
no setter
primarySoft Color
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success Color
no setter
surface Color
no setter
surfaceHover Color
no setter
surfaceMuted Color
no setter
surfaceRaised Color
no setter
surfaceSelected Color
no setter
textPrimary Color
no setter
textSecondary Color
no setter
textTertiary Color
no setter
userMessageSurface Color
no setter
warning Color
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited