MermaidSvgCache class

Constructors

MermaidSvgCache.memory({int maxEntries = 128})

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setter
maxEntries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
get(String key) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String key, String svg) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

keyFor({required String source, required String optionsJson, required String engineVersion}) String