ChatPromptCapabilities class

Constructors

ChatPromptCapabilities({bool files = true, required bool image, required bool audio, required bool embeddedContext})
const
ChatPromptCapabilities.fromRaw(Object? raw)
factory

Properties

audio bool
final
embeddedContext bool
final
files bool
Whether arbitrary file references or uploads are accepted by the host.
final
hashCode int
The hash code for this object.
no setterinherited
image bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? files, bool? image, bool? audio, bool? embeddedContext}) ChatPromptCapabilities
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited