ChatThoughtMessage class
- Inheritance
-
- Object
- ChatMessageData
- ChatThoughtMessage
Constructors
- ChatThoughtMessage({required String text, required int turnId, int revision = 0})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
-
metadata
→ Map<
String, Object?> -
finalinherited
-
omissions
→ List<
ChatInputOmission> -
finalinherited
- previewText → String
-
no setterinherited
- revision → int
-
finalinherited
- role → ChatMessageRole
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
finalinherited
- timestamp → DateTime
-
finalinherited
- turnId → int?
-
finalinherited
Methods
-
copyWith(
{String? text, Map< String, Object?> ? metadata}) → ChatMessageData -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited