ChatBase64ScanResult class final

Constructors

ChatBase64ScanResult(int encodedLength, int decodedBytes)
const

Properties

decodedBytes int
final
encodedLength int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited