ChatTextBudgetChunk class final

Constructors

ChatTextBudgetChunk({required String safePrefix, required int acceptedBytes, required int totalBytes, required int totalLines, ChatInputOmission? omission})
const

Properties

acceptedBytes int
final
hashCode int
The hash code for this object.
no setterinherited
omission ChatInputOmission?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safePrefix String
final
totalBytes int
final
totalLines int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited