ChatUtf8LineBudgetCheckpoint class final

Opaque one-shot host transaction for one ChatUtf8LineBudgetCounter.

This is trusted host bookkeeping, not an untrusted-input security boundary.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited