Read-only projection. Implementations may retain streaming buffers without copying the complete transcript whenever a new token arrives.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, Object?> -
no setter
-
omissions
→ List<
ChatInputOmission> -
no setter
- previewText → String
-
no setter
- revision → int
-
no setter
- role → ChatMessageRole
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
no setter
- timestamp → DateTime
-
no setter
- turnId → int?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited