ChatQueuedPrompt class

Constructors

ChatQueuedPrompt({required int id, required String text, required List<PromptAttachment> attachments, required DateTime createdAt, bool guide = false})
const

Properties

attachments List<PromptAttachment>
final
createdAt DateTime
final
guide bool
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

copyWith({bool? guide}) ChatQueuedPrompt
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited