ChatPermissionChoice class

Constructors

ChatPermissionChoice({required String optionId, required String name, String? kind})
const

Properties

decision ChatPermissionDecision?
no setter
explicitDecision ChatPermissionDecision?
no setter
hashCode int
The hash code for this object.
no setterinherited
isSingleUse bool
no setter
kind String?
final
name String
final
optionId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited