ChatPermissionRequest class
Constructors
-
ChatPermissionRequest({required String id, String lifecycleId = '', required String title, required String rationale, required String sessionId, required String toolName, required List<
String> options, required DateTime requestedAt, List<ChatPermissionChoice> choices = const <ChatPermissionChoice>[], String? toolKind, Map<String, Object?> metadata = const <String, Object?>{}, Map<String, Object?> transientPolicyContext = const <String, Object?>{}, int generation = 0}) -
const
Properties
- allowActionLabel → String
-
no setter
- bindingKey → String
-
no setter
-
choices
→ List<
ChatPermissionChoice> -
final
- contentFingerprint → String
-
no setter
- denyActionLabel → String
-
no setter
- displayKind → String
-
no setter
- displayRationale → String
-
no setter
- displayTitle → String
-
no setter
- generation → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- lifecycleId → String
-
final
-
metadata
→ Map<
String, Object?> -
final
-
options
→ List<
String> -
final
- rationale → String
-
final
- requestedAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- title → String
-
final
- toolKind → String?
-
final
- toolName → String
-
final
-
transientPolicyContext
→ Map<
String, Object?> -
final
- transientPolicyContextFingerprint → String
-
no setter
Methods
-
choiceById(
String optionId) → ChatPermissionChoice? -
forAudit(
{Map< String, Object?> ? metadata, String? title, String? rationale}) → ChatPermissionRequest -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
singleUseChoiceFor(
ChatPermissionDecision decision) → ChatPermissionChoice? -
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
-
withGeneration(
int value) → ChatPermissionRequest
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited