ChatConfigOptionChoice class

Constructors

ChatConfigOptionChoice({required String value, required String name, String? description, String? groupId, String? groupName})
const

Properties

description String?
final
groupId String?
final
groupName String?
final
hashCode int
The hash code for this object.
no setterinherited
label String
no setter
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited