ChatSessionModeInfo class

Constructors

ChatSessionModeInfo({String? currentModeId, List<ChatSessionMode> availableModes = const <ChatSessionMode>[]})
const

Properties

availableModes List<ChatSessionMode>
final
currentModeId String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? currentModeId, List<ChatSessionMode>? availableModes}) ChatSessionModeInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited