ChatSessionSettings class

Constructors

ChatSessionSettings({ChatSessionModeInfo modes = const ChatSessionModeInfo(), List<ChatConfigOption> configOptions = const <ChatConfigOption>[], List<ChatInputOmission> omissions = const <acp.ChatInputOmission>[], bool truncated = false})
const

Properties

configOptions List<ChatConfigOption>
final
currentModelLabel String?
no setter
currentReasoningEffortLabel String?
no setter
hasConfigOptions bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasModes bool
no setter
modelOption ChatConfigOption?
no setter
modes ChatSessionModeInfo
final
nonModelConfigOptions List<ChatConfigOption>
no setter
omissions List<ChatInputOmission>
final
reasoningEffortOption ChatConfigOption?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldUseModeFallback bool
no setter
truncated bool
final
withConfigOptionsPreference ChatSessionSettings
no setter

Methods

copyWith({ChatSessionModeInfo? modes, List<ChatConfigOption>? configOptions, List<ChatInputOmission>? omissions, bool? truncated}) ChatSessionSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withCurrentMode(String modeId) ChatSessionSettings
withPreferredConfigOptions(List<ChatConfigOption> options) ChatSessionSettings

Operators

operator ==(Object other) bool
The equality operator.
inherited