PermissionDisplayContextLimits class

Constructors

PermissionDisplayContextLimits({int maxUtf8Bytes = 16 * 1024, int maxEntries = 16, int maxDepth = 4, int maxNodes = 128})

Properties

hashCode int
The hash code for this object.
no setterinherited
maxDepth int
final
maxEntries int
final
maxNodes int
final
maxUtf8Bytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited