BoundedFileSnapshotOverflowException class final

Raised when a file snapshot contains more bytes than its caller permits.

The exception intentionally retains no file contents.

Implemented types

Constructors

BoundedFileSnapshotOverflowException({required String path, required int maxBytes})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxBytes int
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited