- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createBuffer(
Uint8List bytes) → Future< BoundedImageBuffer> -
createCodec(
BoundedImageDescriptor descriptor, {required int targetWidth, required int targetHeight}) → Future< BoundedImageCodec> -
createDescriptor(
BoundedImageBuffer buffer) → Future< BoundedImageDescriptor> -
getFirstFrame(
BoundedImageCodec codec) → Future< BoundedImageFrame> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited