DartUiBoundedImageDecoder class final

Implemented types

Constructors

DartUiBoundedImageDecoder()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBuffer(Uint8List bytes) Future<BoundedImageBuffer>
override
createCodec(BoundedImageDescriptor descriptor, {required int targetWidth, required int targetHeight}) Future<BoundedImageCodec>
override
createDescriptor(BoundedImageBuffer buffer) Future<BoundedImageDescriptor>
override
getFirstFrame(BoundedImageCodec codec) Future<BoundedImageFrame>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited