ChatTimeline class

Inheritance

Constructors

ChatTimeline({Key? key, required List<ChatMessageView> messages, String agentName = 'Codex', bool hasActiveSession = false, String? activeSessionLabel, bool isLoadingSession = false, int messageListRevision = 0, bool showNewSessionAction = false, VoidCallback? onNewSession, MarkdownTapLinkCallback? onTapLink, ChatInputBudget inputBudget = const ChatInputBudget(), ChatImageDecodeBudgetLedger? imageDecodeLedger, BoundedImageDecoder boundedImageDecoder = const DartUiBoundedImageDecoder(), ToolPresentationRegistry? toolPresentationRegistry})
const

Properties

activeSessionLabel String?
final
agentName String
final
boundedImageDecoder BoundedImageDecoder
final
hasActiveSession bool
final
hashCode int
The hash code for this object.
no setterinherited
imageDecodeLedger ChatImageDecodeBudgetLedger?
final
inputBudget ChatInputBudget
final
isLoadingSession bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
messageListRevision int
final
messages List<ChatMessageView>
final
onNewSession VoidCallback?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNewSessionAction bool
final
toolPresentationRegistry ToolPresentationRegistry?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ChatTimeline>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited