PromptInput class

Inheritance

Constructors

PromptInput({Key? key, String agentName = 'Codex', bool enabled = true, required bool isSending, bool promptAppearsStalled = false, required PromptSendCallback onSend, required VoidCallback onStop, bool showAttachmentControl = true, bool showExecutionPolicy = true, bool canQueueWhileSending = true, List<Map<String, Object?>> availableCommands = const <Map<String, Object?>>[], int availableCommandsRevision = 0, ChatPromptCapabilities? promptCapabilities, ChatPermissionRequest? pendingPermissionRequest, VoidCallback? onAllowPermission, VoidCallback? onDenyPermission, VoidCallback? onCancelPermission, ValueChanged<String>? onSelectPermissionOption, ChatToolCallExecutionPolicy toolCallExecutionPolicy = ChatToolCallExecutionPolicy.defaultPermissions, bool hasPermissionReviewer = false, ValueChanged<ChatToolCallExecutionPolicy>? onToolCallExecutionPolicyChanged, ChatConfigOption? modelOption, ChatConfigOption? reasoningEffortOption, ValueChanged<String>? onModelSelected, ValueChanged<String>? onReasoningEffortSelected, List<ChatConfigOption> configOptions = const <ChatConfigOption>[], SessionConfigSelectionCallback? onConfigOptionSelected, PromptAttachmentPicker? pickAttachments, PromptAttachmentKindPicker? pickAttachmentsForKind, PromptAttachmentController? attachmentController, PromptImageClipboardReader readClipboardImage = emptyClipboardImage, PromptDroppedImageReader readDroppedImage = readDroppedImageAttachment, List<String> workspaceRoots = const <String>[], String? imageAttachmentLimitation, List<String> promptHistory = const <String>[], List<ChatQueuedPrompt> queuedPrompts = const <ChatQueuedPrompt>[], ValueChanged<int>? onGuideQueuedPrompt, ValueChanged<int>? onRemoveQueuedPrompt, VoidCallback? onClearQueuedPrompts, void onReorderQueuedPrompt(int oldIndex, int newIndex)?, ChatInputBudget inputBudget = const ChatInputBudget()})
const

Properties

agentName String
final
attachmentController PromptAttachmentController?
final
availableCommands List<Map<String, Object?>>
final
availableCommandsRevision int
final
canQueueWhileSending bool
final
configOptions List<ChatConfigOption>
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
hasPermissionReviewer bool
final
imageAttachmentLimitation String?
final
inputBudget ChatInputBudget
final
isSending bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
modelOption ChatConfigOption?
final
onAllowPermission VoidCallback?
final
onCancelPermission VoidCallback?
final
onClearQueuedPrompts VoidCallback?
final
onConfigOptionSelected SessionConfigSelectionCallback?
final
onDenyPermission VoidCallback?
final
onGuideQueuedPrompt ValueChanged<int>?
final
onModelSelected ValueChanged<String>?
final
onReasoningEffortSelected ValueChanged<String>?
final
onRemoveQueuedPrompt ValueChanged<int>?
final
onReorderQueuedPrompt → void Function(int oldIndex, int newIndex)?
final
onSelectPermissionOption ValueChanged<String>?
final
onSend PromptSendCallback
final
onStop VoidCallback
final
onToolCallExecutionPolicyChanged ValueChanged<ChatToolCallExecutionPolicy>?
final
pendingPermissionRequest ChatPermissionRequest?
final
pickAttachments PromptAttachmentPicker?
final
pickAttachmentsForKind PromptAttachmentKindPicker?
final
promptAppearsStalled bool
final
promptCapabilities ChatPromptCapabilities?
final
promptHistory List<String>
final
queuedPrompts List<ChatQueuedPrompt>
final
readClipboardImage PromptImageClipboardReader
final
readDroppedImage PromptDroppedImageReader
final
reasoningEffortOption ChatConfigOption?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAttachmentControl bool
final
showExecutionPolicy bool
final
toolCallExecutionPolicy ChatToolCallExecutionPolicy
final
workspaceRoots List<String>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PromptInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited