AppTypography class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- body → const TextStyle
- bodyCompact → const TextStyle
- code → const TextStyle
- dialogTitle → const TextStyle
- family → const String
-
familyFallback
→ const List<
String> - label → const TextStyle
- metadata → const TextStyle
-
monoFallback
→ const List<
String> - monoFamily → const String
- pageTitle → const TextStyle
- sectionTitle → const TextStyle