ChatCapabilities class
Features advertised by a particular conversation, not assumed from a brand.
Constructors
- ChatCapabilities({ChatPromptCapabilities prompt = const ChatPromptCapabilities(image: false, audio: false, embeddedContext: false), bool attachments = false, bool tools = false, bool permissions = false, bool executionPolicy = false, bool queue = false, bool restore = false})
-
const
Properties
- attachments → bool
-
final
- executionPolicy → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- permissions → bool
-
final
- prompt → ChatPromptCapabilities
-
final
- queue → bool
-
final
- restore → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tools → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited