ChatSessionState class
One atomic visible snapshot. Hosts keep replay staging and persistence out of the widget tree. Bump messagesRevision on in-place transcript updates.
Constructors
-
ChatSessionState({required Object identity, required String agentName, required List<
ChatMessageView> messages, String? title, bool hasSession = true, bool isLoading = false, bool enabled = true, bool isSending = false, bool promptAppearsStalled = false, int messagesRevision = 0, ChatCapabilities capabilities = const ChatCapabilities(), List<Map< commands = const [], int commandsRevision = 0, ChatPermissionRequest? permission, ChatToolCallExecutionPolicy executionPolicy = ChatToolCallExecutionPolicy.defaultPermissions, bool hasPermissionReviewer = false, List<String, Object?> >ChatConfigOption> configOptions = const [], List<ChatQueuedPrompt> queuedPrompts = const [], List<String> workspaceRoots = const [], String? imageAttachmentLimitation, String? error, ChatInputBudget inputBudget = const ChatInputBudget()}) -
const
Properties
- agentName → String
-
final
- capabilities → ChatCapabilities
-
final
-
commands
→ List<
Map< String, Object?> > -
final
- commandsRevision → int
-
final
-
configOptions
→ List<
ChatConfigOption> -
final
- enabled → bool
-
final
- error → String?
-
final
- executionPolicy → ChatToolCallExecutionPolicy
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPermissionReviewer → bool
-
final
- hasSession → bool
-
final
- identity → Object
-
final
- imageAttachmentLimitation → String?
-
final
- inputBudget → ChatInputBudget
-
final
- isLoading → bool
-
final
- isSending → bool
-
final
-
messages
→ List<
ChatMessageView> -
final
- messagesRevision → int
-
final
- permission → ChatPermissionRequest?
-
final
- promptAppearsStalled → bool
-
final
-
queuedPrompts
→ List<
ChatQueuedPrompt> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
-
workspaceRoots
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited