ChatInputOmission class final
A typed description of ACP input that owning code omitted.
Constructors
- ChatInputOmission({required ChatInputOmissionReason reason, required String resource, required bool truncated, int? limit, int? observedAtLeast})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
final
- observedAtLeast → int?
-
final
- reason → ChatInputOmissionReason
-
final
- resource → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- truncated → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited