ChatConfigOption class
Constructors
-
ChatConfigOption({required String id, required String name, required String type, required String currentValue, required List<
ChatConfigOptionChoice> options, String? description, String? category, String? group}) -
const
Properties
- category → String?
-
final
- currentBoolValue → bool
-
no setter
- currentChoiceLabel → String
-
no setter
- currentValue → String
-
final
- description → String?
-
final
- group → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isBooleanOption → bool
-
no setter
- isFastEnabled → bool
-
no setter
- isFastOption → bool
-
no setter
- isModelOption → bool
-
no setter
- isReasoningEffortOption → bool
-
no setter
- name → String
-
final
-
options
→ List<
ChatConfigOptionChoice> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
copyWith(
{Object? currentValue}) → ChatConfigOption -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited