PromptAttachment class
Constructors
- PromptAttachment({required String path, required String name, String? mimeType, int? size, String? data, bool userApprovedOutsideWorkspace = false, bool forceResourceLink = false})
-
const
- PromptAttachment.fromBytes({required Uint8List bytes, required String name, required String mimeType})
-
factory
- PromptAttachment.fromPath({required String path, String? name, String? mimeType, int? size, bool userApprovedOutsideWorkspace = false, bool forceResourceLink = false})
-
factory
Properties
- audioMimeType → String?
-
no setter
- data → String?
-
final
- displaySize → String
-
no setter
- forceResourceLink → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- identity → String
-
no setter
- imageMimeType → String?
-
no setter
- isAudio → bool
-
no setter
- isGenericBinary → bool
-
no setter
- isImage → bool
-
no setter
- isInline → bool
-
no setter
- isText → bool
-
no setter
- mimeType → String?
-
final
- name → String
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int?
-
final
- uri → Uri
-
no setter
- userApprovedOutsideWorkspace → bool
-
final
Methods
-
copyWith(
{String? path, String? name, String? mimeType, int? size, String? data, bool? userApprovedOutsideWorkspace, bool? forceResourceLink}) → PromptAttachment -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
promptMode(
ChatPromptCapabilities? capabilities) → PromptAttachmentPromptMode -
toPromptMention(
) → String -
toResourceLink(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override