ChatPlatformServices class
Override platform access at the embedding boundary. Defaults use standard desktop pickers/files; no host-specific MethodChannel or workspace exists.
Constructors
-
ChatPlatformServices({Future<
List< pickAttachments(PromptAttachmentKind kind) = platform.pickPlatformAttachments, Future<PromptAttachment> >PromptAttachment?> readImage(PromptAttachment attachment) = platform.readDroppedImageAttachment, ChatPathResolver resolvePath = platform.resolvePlatformPath, ImageProvider<Object> imageForPath(String path) = platform.platformImageForPath, String workingDirectory() = platform.platformWorkingDirectory}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageForPath
→ ImageProvider<
Object> Function(String path) -
final
-
pickAttachments
→ Future<
List< Function(PromptAttachmentKind kind)PromptAttachment> > -
final
-
readImage
→ Future<
PromptAttachment?> Function(PromptAttachment attachment) -
final
- resolvePath → ChatPathResolver
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workingDirectory → String Function()
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited