ToolActivityPresentation class final
Pure data consumed by the timeline's common tool-row renderer.
Constructors
- ToolActivityPresentation({required ToolActivityKind kind, required IconData icon, required String action, required String subject, String suffix = '', bool linkSubject = false})
-
const
Properties
- action → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
final
- kind → ToolActivityKind
-
final
- linkSubject → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String
-
no setter
- subject → String
-
final
- suffix → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited