ToolPresentationSource class final
The normalized, renderer-independent projection of one ACP tool update.
Constructors
-
ToolPresentationSource({required String title, required String status, required String id, required String kind, required Object? content, required Object? input, required Object? output, required List<
String> locations, required Object previewRevision}) -
const
- ToolPresentationSource.fromMessage(ChatMessageView message)
-
factory
Properties
- content → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- input → Object?
-
final
- kind → String
-
final
-
locations
→ List<
String> -
final
- output → Object?
-
final
- previewRevision → Object
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited